@@ -1,5 +1,7 @@
 """
-Main interface for ce service client
+Type annotations for ce service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
 
 Usage::
 
@@ -10,6 +12,7 @@ Usage::
     client: CostExplorerClient = boto3.client("ce")
     ```
 """
+import sys
 from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
@@ -19,7 +22,6 @@ from mypy_boto3_ce.literals import (
     AnomalyFeedbackType,
     AnomalySubscriptionFrequency,
     Context,
-    CostCategoryRuleVersion,
     Dimension,
     Granularity,
     LookbackPeriodInDays,
@@ -40,6 +42,7 @@ from mypy_boto3_ce.type_defs import (
     DateIntervalTypeDef,
     DeleteCostCategoryDefinitionResponseTypeDef,
     DescribeCostCategoryDefinitionResponseTypeDef,
+    ExpressionTypeDef,
     GetAnomaliesResponseTypeDef,
     GetAnomalyMonitorsResponseTypeDef,
     GetAnomalySubscriptionsResponseTypeDef,
@@ -71,6 +74,12 @@ from mypy_boto3_ce.type_defs import (
     UpdateCostCategoryDefinitionResponseTypeDef,
 )
 
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    from typing_extensions import Literal
+
+
 __all__ = ("CostExplorerClient",)
 
 
@@ -98,7 +107,8 @@ class Exceptions:
 
 class CostExplorerClient:
     """
-    [CostExplorer.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html)
     """
 
     meta: ClientMeta
@@ -106,56 +116,64 @@ class CostExplorerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#can-paginate)
         """
 
     def create_anomaly_monitor(
         self, AnomalyMonitor: "AnomalyMonitorTypeDef"
     ) -> CreateAnomalyMonitorResponseTypeDef:
         """
-        [Client.create_anomaly_monitor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create-anomaly-monitor)
         """
 
     def create_anomaly_subscription(
         self, AnomalySubscription: "AnomalySubscriptionTypeDef"
     ) -> CreateAnomalySubscriptionResponseTypeDef:
         """
-        [Client.create_anomaly_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create-anomaly-subscription)
         """
 
     def create_cost_category_definition(
         self,
         Name: str,
-        RuleVersion: CostCategoryRuleVersion,
+        RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
         DefaultValue: str = None,
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.create_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#create-cost-category-definition)
         """
 
     def delete_anomaly_monitor(self, MonitorArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_anomaly_monitor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete-anomaly-monitor)
         """
 
     def delete_anomaly_subscription(self, SubscriptionArn: str) -> Dict[str, Any]:
         """
-        [Client.delete_anomaly_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete-anomaly-subscription)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.delete_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#delete-cost-category-definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.describe_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#describe-cost-category-definition)
         """
 
     def generate_presigned_url(
@@ -166,7 +184,8 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#generate-presigned-url)
         """
 
     def get_anomalies(
@@ -179,14 +198,16 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetAnomaliesResponseTypeDef:
         """
-        [Client.get_anomalies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-anomalies)
         """
 
     def get_anomaly_monitors(
         self, MonitorArnList: List[str] = None, NextPageToken: str = None, MaxResults: int = None
     ) -> GetAnomalyMonitorsResponseTypeDef:
         """
-        [Client.get_anomaly_monitors documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-anomaly-monitors)
         """
 
     def get_anomaly_subscriptions(
@@ -197,7 +218,8 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetAnomalySubscriptionsResponseTypeDef:
         """
-        [Client.get_anomaly_subscriptions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-anomaly-subscriptions)
         """
 
     def get_cost_and_usage(
@@ -205,25 +227,27 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         Granularity: Granularity,
         Metrics: List[str],
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Client.get_cost_and_usage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-and-usage)
         """
 
     def get_cost_and_usage_with_resources(
         self,
         TimePeriod: "DateIntervalTypeDef",
         Granularity: Granularity,
-        Filter: Dict[str, Any],
+        Filter: "ExpressionTypeDef",
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Client.get_cost_and_usage_with_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-and-usage-with-resources)
         """
 
     def get_cost_categories(
@@ -231,13 +255,14 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         SearchString: str = None,
         CostCategoryName: str = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         SortBy: List[SortDefinitionTypeDef] = None,
         MaxResults: int = None,
         NextPageToken: str = None,
     ) -> GetCostCategoriesResponseTypeDef:
         """
-        [Client.get_cost_categories documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-categories)
         """
 
     def get_cost_forecast(
@@ -245,11 +270,12 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         Metric: Metric,
         Granularity: Granularity,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Client.get_cost_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-cost-forecast)
         """
 
     def get_dimension_values(
@@ -258,13 +284,14 @@ class CostExplorerClient:
         Dimension: Dimension,
         SearchString: str = None,
         Context: Context = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         SortBy: List[SortDefinitionTypeDef] = None,
         MaxResults: int = None,
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Client.get_dimension_values documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-dimension-values)
         """
 
     def get_reservation_coverage(
@@ -272,21 +299,22 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Granularity = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextPageToken: str = None,
         SortBy: SortDefinitionTypeDef = None,
         MaxResults: int = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Client.get_reservation_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-reservation-coverage)
         """
 
     def get_reservation_purchase_recommendation(
         self,
         Service: str,
         AccountId: str = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         AccountScope: AccountScope = None,
         LookbackPeriodInDays: LookbackPeriodInDays = None,
         TermInYears: TermInYears = None,
@@ -296,7 +324,8 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_reservation_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-reservation-purchase-recommendation)
         """
 
     def get_reservation_utilization(
@@ -304,25 +333,27 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Granularity = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         SortBy: SortDefinitionTypeDef = None,
         NextPageToken: str = None,
         MaxResults: int = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Client.get_reservation_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-reservation-utilization)
         """
 
     def get_rightsizing_recommendation(
         self,
         Service: str,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         Configuration: "RightsizingRecommendationConfigurationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Client.get_rightsizing_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-rightsizing-recommendation)
         """
 
     def get_savings_plans_coverage(
@@ -330,14 +361,15 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         Granularity: Granularity = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextToken: str = None,
         MaxResults: int = None,
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Client.get_savings_plans_coverage documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
@@ -349,34 +381,37 @@ class CostExplorerClient:
         AccountScope: AccountScope = None,
         NextPageToken: str = None,
         PageSize: int = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Client.get_savings_plans_purchase_recommendation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-purchase-recommendation)
         """
 
     def get_savings_plans_utilization(
         self,
         TimePeriod: "DateIntervalTypeDef",
         Granularity: Granularity = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-utilization)
         """
 
     def get_savings_plans_utilization_details(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         DataType: List[SavingsPlansDataType] = None,
         NextToken: str = None,
         MaxResults: int = None,
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Client.get_savings_plans_utilization_details documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-savings-plans-utilization-details)
         """
 
     def get_tags(
@@ -384,13 +419,14 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         SearchString: str = None,
         TagKey: str = None,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         SortBy: List[SortDefinitionTypeDef] = None,
         MaxResults: int = None,
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Client.get_tags documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-tags)
         """
 
     def get_usage_forecast(
@@ -398,32 +434,36 @@ class CostExplorerClient:
         TimePeriod: "DateIntervalTypeDef",
         Metric: Metric,
         Granularity: Granularity,
-        Filter: Dict[str, Any] = None,
+        Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Client.get_usage_forecast documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#get-usage-forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Client.list_cost_category_definitions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#list-cost-category-definitions)
         """
 
     def provide_anomaly_feedback(
         self, AnomalyId: str, Feedback: AnomalyFeedbackType
     ) -> ProvideAnomalyFeedbackResponseTypeDef:
         """
-        [Client.provide_anomaly_feedback documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#provide-anomaly-feedback)
         """
 
     def update_anomaly_monitor(
         self, MonitorArn: str, MonitorName: str = None
     ) -> UpdateAnomalyMonitorResponseTypeDef:
         """
-        [Client.update_anomaly_monitor documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update-anomaly-monitor)
         """
 
     def update_anomaly_subscription(
@@ -436,16 +476,18 @@ class CostExplorerClient:
         SubscriptionName: str = None,
     ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
-        [Client.update_anomaly_subscription documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update-anomaly-subscription)
         """
 
     def update_cost_category_definition(
         self,
         CostCategoryArn: str,
-        RuleVersion: CostCategoryRuleVersion,
+        RuleVersion: Literal["CostCategoryExpression.v1"],
         Rules: List["CostCategoryRuleTypeDef"],
         DefaultValue: str = None,
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Client.update_cost_category_definition documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.64/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ce/client.html#update-cost-category-definition)
         """
